@@ -40,11 +40,6 @@
 #define UNUSED_VARIABLE
 #endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X, Y) gtk_box_new(GTK_ORIENTATION_VERTICAL, Y)
-#define gtk_hbox_new(X, Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL, Y)
-#endif
-
 typedef struct {
 	FrWindow    *window;
 	GSettings   *settings;
@@ -218,7 +213,7 @@ add_folder_cb (GtkWidget *widget,
 	DialogData  *data;
 	GtkWidget   *main_box;
 	GtkWidget   *vbox;
-	GtkWidget   *table;
+	GtkWidget   *grid;
 	GtkWidget   *align;
 
 	data = g_new0 (DialogData, 1);
@@ -247,30 +242,42 @@ add_folder_cb (GtkWidget *widget,
 	data->include_files_entry = gtk_entry_new ();
 	gtk_widget_set_tooltip_text (data->include_files_entry, _("example: *.o; *.bak"));
 	data->include_files_label = gtk_label_new_with_mnemonic (_("Include _files:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (data->include_files_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (data->include_files_label), 0.0, 0.5);
+#endif
 	gtk_label_set_mnemonic_widget (GTK_LABEL (data->include_files_label), data->include_files_entry);
 
 	data->exclude_files_entry = gtk_entry_new ();
 	gtk_widget_set_tooltip_text (data->exclude_files_entry, _("example: *.o; *.bak"));
 	data->exclude_files_label = gtk_label_new_with_mnemonic (_("E_xclude files:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (data->exclude_files_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (data->exclude_files_label), 0.0, 0.5);
+#endif
 	gtk_label_set_mnemonic_widget (GTK_LABEL (data->exclude_files_label), data->exclude_files_entry);
 
 	data->exclude_folders_entry = gtk_entry_new ();
 	gtk_widget_set_tooltip_text (data->exclude_folders_entry, _("example: *.o; *.bak"));
 	data->exclude_folders_label = gtk_label_new_with_mnemonic (_("_Exclude folders:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (data->exclude_folders_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (data->exclude_folders_label), 0.0, 0.5);
+#endif
 	gtk_label_set_mnemonic_widget (GTK_LABEL (data->exclude_folders_label), data->exclude_folders_entry);
 
 	data->load_button = gtk_button_new_with_mnemonic (_("_Load Options"));
 	data->save_button = gtk_button_new_with_mnemonic (_("Sa_ve Options"));
 	data->clear_button = gtk_button_new_with_mnemonic (_("_Reset Options"));
 
-	main_box = gtk_hbox_new (FALSE, 20);
+	main_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 20);
 	gtk_container_set_border_width (GTK_CONTAINER (main_box), 0);
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (file_sel), main_box);
 
-	vbox = gtk_vbox_new (FALSE, 6);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 	gtk_box_pack_start (GTK_BOX (main_box), vbox, TRUE, TRUE, 0);
 
@@ -285,52 +292,40 @@ add_folder_cb (GtkWidget *widget,
 	gtk_box_pack_start (GTK_BOX (vbox), data->add_if_newer_checkbutton,
 			    TRUE, TRUE, 0);
 
-	table = gtk_table_new (2, 4, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-	gtk_box_pack_start (GTK_BOX (vbox), table,
+	grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
+	gtk_box_pack_start (GTK_BOX (vbox), grid,
 			    TRUE, TRUE, 0);
 
-	gtk_table_attach (GTK_TABLE (table),
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->include_files_label,
-			  0, 1,
-			  0, 1,
-			  GTK_FILL, 0,
-			  0, 0);
-	gtk_table_attach (GTK_TABLE (table),
+			  0, 0,
+			  1, 1);
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->include_files_entry,
-			  1, 4,
-			  0, 1,
-			  GTK_FILL|GTK_EXPAND, 0,
-			  0, 0);
-	gtk_table_attach (GTK_TABLE (table),
+			  1, 0,
+			  3, 1);
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->exclude_files_label,
 			  0, 1,
-			  1, 2,
-			  GTK_FILL, 0,
-			  0, 0);
-	gtk_table_attach (GTK_TABLE (table),
+			  1, 1);
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->exclude_files_entry,
-			  1, 2,
-			  1, 2,
-			  GTK_FILL|GTK_EXPAND, 0,
-			  0, 0);
-	gtk_table_attach (GTK_TABLE (table),
+			  1, 1,
+			  1, 1);
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->exclude_folders_label,
-			  2, 3,
-			  1, 2,
-			  GTK_FILL, 0,
-			  0, 0);
-	gtk_table_attach (GTK_TABLE (table),
+			  2, 1,
+			  1, 1);
+	gtk_grid_attach (GTK_GRID (grid),
 			  data->exclude_folders_entry,
-			  3, 4,
-			  1, 2,
-			  GTK_FILL|GTK_EXPAND, 0,
-			  0, 0);
+			  3, 1,
+			  1, 1);
 
 	/**/
 
-	vbox = gtk_vbox_new (FALSE, 5);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 	gtk_box_pack_start (GTK_BOX (main_box), vbox, FALSE, FALSE, 0);
 
@@ -806,7 +801,7 @@ load_options_cb (GtkWidget  *w,
 	aod_data = g_new0 (LoadOptionsDialogData, 1);
 
 	aod_data->data = data;
-	aod_data->builder = _gtk_builder_new_from_file ("add-options.ui");
+	aod_data->builder = _gtk_builder_new_from_resource ("add-options.ui");
 	if (aod_data->builder == NULL) {
 		g_free (aod_data);
 		return;
