@@ -284,7 +284,7 @@ process_line__add (char     *line,
 {
 	FrCommand *comm = FR_COMMAND (data);
 
-	if ((comm->volume_size > 0) && (strncmp (line, "Creating archive ", 17) == 0)) {
+	if ((comm->volume_size > 0) && (strncmp (line, "Creating archive", 16) == 0)) {
 		char  *volume_filename;
 		GFile *volume_file;
 
@@ -362,7 +362,11 @@ fr_command_7z_add (FrCommand     *comm,
 		break;
 	case FR_COMPRESSION_MAXIMUM:
 		fr_process_add_arg (comm->process, "-mx=9");
-		fr_process_add_arg (comm->process, "-m0=lzma2");;
+		if (! is_mime_type (comm->mime_type, "application/zip")
+		    && ! is_mime_type (comm->mime_type, "application/x-cbz"))
+		{
+			fr_process_add_arg (comm->process, "-m0=lzma2");;
+		}
 		break;
 	}
 
@@ -418,6 +422,8 @@ fr_command_7z_delete (FrCommand  *comm,
 			if (g_str_has_prefix (scan->data, "@"))
 				fr_process_add_arg_concat (comm->process, "-i!", scan->data, NULL);
 
+	add_password_arg (comm, FR_COMMAND (comm)->password, FALSE);
+
 	fr_process_add_arg (comm->process, "--");
 	fr_process_add_arg (comm->process, comm->filename);
 
